Coverage for appr/platforms/helm.py: 0%

# Coverage for appr/platforms/helm.py : 0%

## 12 statements 0 run 12 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 | from __future__ import absolute_import, division, print_function __all__ = ['Helm'] class Helm(object): def action(self, cmd, package_path, helm_opts=None): cmd = [cmd] if helm_opts: cmd = cmd + helm_opts cmd.append(package_path) return self._call(cmd) def _call(self, cmd): command = ['helm'] + cmd return subprocess.check_output(command, stderr=subprocess.STDOUT)